@@ -1,9 +1,10 @@
 package Dist::Zilla::PluginBundle::Author::IOANR;
-$Dist::Zilla::PluginBundle::Author::IOANR::VERSION = '1.162690';
+$Dist::Zilla::PluginBundle::Author::IOANR::VERSION = '1.162691';
 # ABSTRACT: Build dists the way IOANR likes
 use v5.12;
 use Moose;
 use List::Util 1.33 'any';
+use Dist::Zilla::Plugin::AssertOS;
 use Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes 0.107;
 use Dist::Zilla::Plugin::ContributorsFile;
 use Dist::Zilla::Plugin::CopyFilesFromBuild;
@@ -113,7 +114,7 @@ sub configure {
                 exclude_match    => '(Changes|README.md|LICENSE)$',
             }
         ],
-        'GitHub::Meta',
+        ['GitHub::Meta' => {metacpan => 1 }],
         'License',
         'Manifest',
         'Meta::Contributors',
@@ -187,7 +188,7 @@ Dist::Zilla::PluginBundle::Author::IOANR - Build dists the way IOANR likes
 
 =head1 VERSION
 
-version 1.162690
+version 1.162691
 
 =head1 OPTIONS
 
